"""
Convenience wrapper for xwformats.
This module provides the 'xwformats' package as a lightweight wrapper
that imports from 'exonware-xwformats'. Install the full package as a dependency.
Company: eXonware.com
Author: eXonware Backend Team
Email: connect@exonware.com
Version: 0.9.0.22
"""
# Import everything from the full package

from exonware.xwformats import *  # noqa: F401, F403
